@@ -26,5 +26,5 @@ class Cache:
     def update_local_cache_version_with_redis_version(self):
         self._local_cache_version = self.get_redis_cache_version()
 
-    def clear_cache(self):
+    def increase_redis_version(self):
         self._get_cache().incr_value(self._redis_key)
