@@ -44,9 +44,7 @@ class RedisCache:
 
             return connection
         except Exception as e:
-            rg_logger.exception(e, "RedisCache->__init_redis_connection_with_host()->>")
-
-        return None
+            raise RGRedisException("Error in Redis Connection, method=RedisCache->__init_redis_connection_with_settings")
 
     @staticmethod
     def __get_redis_settings(redis_setting_key: str) -> dict:
@@ -65,7 +63,7 @@ class RedisCache:
                 redis_connection.hset(redis_key, _hash_key, str(_hash_value))
             except Exception as e:
                 rg_logger.exception(e, "RedisCache->put_value_in_hash_set()->>")
-                raise RGRedisException("RedisCache->put_value_in_hash_set()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->put_value_in_hash_set()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=put_value_in_hash_set")
 
@@ -76,8 +74,7 @@ class RedisCache:
             try:
                 return redis_connection.hget(redis_key, _key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->get_value_from_hash_set()->>")
-                raise RGRedisException("RedisCache->get_value_from_hash_set()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->get_value_from_hash_set()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=get_value_from_hash_set")
 
@@ -88,8 +85,7 @@ class RedisCache:
             try:
                 return redis_connection.hgetall(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->get_all_values_from_hash_set()->>")
-                raise RGRedisException("RedisCache->get_all_values_from_hash_set()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->get_all_values_from_hash_set()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=get_all_values_from_hash_set")
 
@@ -100,8 +96,7 @@ class RedisCache:
             try:
                 return redis_connection.hdel(_redis_key, _hash_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->remove_value_from_hash_set()->>")
-                raise RGRedisException("RedisCache->remove_value_from_hash_set()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->remove_value_from_hash_set()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=remove_value_from_hash_set")
 
@@ -112,8 +107,7 @@ class RedisCache:
             try:
                 return redis_connection.delete(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->delete_key_from_cache()->>")
-                raise RGRedisException("RedisCache->delete_key_from_cache()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->delete_key_from_cache()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=delete_key_from_cache")
 
@@ -124,8 +118,7 @@ class RedisCache:
             try:
                 return redis_connection.set(_redis_key, _value)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->put_string_value()->>")
-                raise RGRedisException("RedisCache->put_string_value()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->put_string_value()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=put_string_value")
 
@@ -136,8 +129,7 @@ class RedisCache:
             try:
                 return redis_connection.get(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->get_string_value()->>")
-                raise RGRedisException("RedisCache->get_string_value()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->get_string_value()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=get_string_value")
 
@@ -148,7 +140,6 @@ class RedisCache:
             try:
                 return redis_connection.incr(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache->get_string_value()->>")
-                raise RGRedisException("RedisCache->incr_value()->>" + rg_logger.get_exception_msg())
+                raise RGRedisException("RedisCache->incr_value()->>" + rg_logger.get_exception_msg(e))
         else:
             raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=incr_value")
